/*
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU Library General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 *
 *  (c) XNeur Team 2006
 *
 */

#ifndef _COLORS_H_
#define _COLORS_H_

#define RED_COLOR		"\033[0;31m"
#define GREEN_COLOR		"\033[0;32m"
#define ORANGE_COLOR		"\033[0;33m"
#define BLUE_COLOR		"\033[0;34m"
#define TEAL_COLOR		"\033[0;36m"
#define LIGHT_YELLOW_COLOR	"\033[1;33m"
#define LIGHT_BLUE_COLOR	"\033[1;34m"
#define LIGHT_PURPLE_COLOR	"\033[1;35m"
#define NORMAL_COLOR		"\033[0m"

#endif /* _COLORS_H_ */
